@@ -1,7 +1,7 @@
 package uSAC::MIME;
 use strict;
 use warnings;
-use version; our $VERSION=version->declare("v0.2.2");
+use version; our $VERSION=version->declare("v0.1");
 
 #Private storage for the internal database
 my $default_mime_to_ext;
@@ -82,7 +82,7 @@ sub index{
 	for my $mime (keys $db->%*){
 		for($db->{$mime}){
 			my $exts=[split " "];
-			push @tmp, map {$_,$mime} @$exts;
+			push @tmp, map {$_,$mime} $exts->@*;
 			push @tmp2, $mime, $exts
 
 		}
@@ -166,7 +166,6 @@ image/x-icon                                     ico
 image/x-jng                                      jng
 image/x-ms-bmp                                   bmp
 
-font/ttf                                         ttf
 font/woff                                        woff
 font/woff2                                       woff2
 
@@ -212,7 +211,6 @@ application/x-xpinstall                          xpi
 application/xhtml+xml                            xhtml
 application/xspf+xml                             xspf
 application/zip                                  zip
-application/gzip				 gz
 
 application/octet-stream                         bin exe dll
 application/octet-stream                         deb
